@@ -5,10 +5,10 @@
 
 from typing import Union
 
-import qtawesome as qta
-from qtpy import QtCore, QtGui, QtWidgets
+from qtpy import QtCore, QtWidgets
 
 from prettyqt import gui, widgets
+from prettyqt.utils import icons
 
 QtWidgets.QDialog.__bases__ = (widgets.Widget,)
 
@@ -55,16 +55,13 @@ class BaseDialog(QtWidgets.QDialog):
         self.box += widget
         return widget
 
-    def set_icon(self, icon: Union[QtGui.QIcon, str, None]):
+    def set_icon(self, icon: icons.IconType):
         """set the icon for the menu
 
         Args:
             icon: icon to use
         """
-        if not icon:
-            icon = gui.Icon()
-        elif isinstance(icon, str):
-            icon = qta.icon(icon, color="lightgray")
+        icon = icons.get_icon(icon, color="lightgray")
         self.setWindowIcon(icon)
 
     def add_buttonbox(self):
