@@ -53,13 +53,16 @@ def test_font():
     repr(font)
     font.metrics
     font = gui.Font.mono()
+    with pytest.raises(ValueError):
+        font.set_style_hint("test")
+    font.set_style_hint("monospace")
 
 
 def test_fontmetrics():
     font = gui.Font("Consolas")
     fontmetrics = gui.FontMetrics(font)
     val = fontmetrics.elided_text("This is a test", mode="right", width=40)
-    assert len(val) == 3
+    assert len(val) < 5
 
 
 def test_icon():
@@ -95,6 +98,7 @@ def test_standarditem():
         s = pickle.load(jar)
     repr(s)
     s.set_icon("mdi.timer")
+    s.clone()
 
 
 def test_standarditemmodel():
@@ -118,7 +122,11 @@ def test_textcursor():
     cursor.set_position(1, "move")
     cursor.move_position("start", "move", 1)
     cursor.select("document")
+    cursor.replace_text(0, 2, "test")
     cursor.select_text(1, 3)
+    cursor.span()
+    with cursor.edit_block():
+        pass
 
 
 def test_painter():
@@ -202,6 +210,9 @@ def test_textcharformat():
     fmt.set_background_color("yellow")
     with pytest.raises(ValueError):
         fmt.set_font_weight("test")
+    fmt = gui.TextCharFormat(bold=True)
+    assert fmt.get_font_weight() == "bold"
+    fmt.select_full_width()
 
 
 def test_validator():
